@@ -1,6 +1,6 @@
 package CatalystX::Resource::TraitFor::Controller::Resource::Edit;
 {
-  $CatalystX::Resource::TraitFor::Controller::Resource::Edit::VERSION = '0.004001';
+  $CatalystX::Resource::TraitFor::Controller::Resource::Edit::VERSION = '0.004002';
 }
 
 use MooseX::MethodAttributes::Role;
@@ -31,6 +31,7 @@ sub edit : Method('GET') Method('POST') Chained('base_with_id') PathPart('edit')
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -39,14 +40,14 @@ CatalystX::Resource::TraitFor::Controller::Resource::Edit - a edit action for yo
 
 =head1 VERSION
 
-version 0.004001
+version 0.004002
 
 =head1 ATTRIBUTES
 
 =head2 activate_fields_edit
 
-hashref of form fields to activate in the edit form
-default = []
+arrayref of form fields to activate in the edit form
+(default = []).
 Can be overriden with $c->stash->{activate_form_fields}
 
 =head1 ACTIONS
@@ -67,4 +68,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
